@@ -46,8 +46,6 @@ class Alert
   void setHeaderCart(unsigned cartnum);
   unsigned eomCart() const;
   void setEomCart(unsigned cartnum);
-  unsigned silenceCart() const;
-  void setSilenceCart(int cartnum);
   unsigned attentionCart() const;
   void setAttentionCart(unsigned cartnum);
   unsigned messageCart() const;
@@ -57,6 +55,7 @@ class Alert
   void clear();
 
  private:
+  int UtcOffset() const;
   QString alert_filename;
   int alert_touches;
   QString alert_eas_type;
@@ -70,7 +69,6 @@ class Alert
   QString alert_message_audio;
   QString alert_text;
   unsigned alert_header_cart;
-  unsigned alert_silence_cart;
   unsigned alert_attention_cart;
   unsigned alert_eom_cart;
   unsigned alert_message_cart;
