@@ -108,6 +108,12 @@ QString Config::pathsEasDataDirectory() const
 }
 
 
+QString Config::pathsEasBackupDirectory() const
+{
+  return conf_paths_eas_backup_directory;
+}
+
+
 QString Config::pathsEasMessageExtension() const
 {
   return conf_paths_eas_message_extension;
@@ -148,6 +154,28 @@ int Config::outroCart(const QString &code) const
 }
 
 
+int Config::liveassistIntroCart(const QString &code) const
+{
+  int ret=conf_liveassist_intro_carts.value(code,-1);
+
+  if(ret<0) {
+    ret=rivendellLiveassistFriendlyIntroCart();
+  }
+  return ret;
+}
+
+
+int Config::liveassistOutroCart(const QString &code) const
+{
+  int ret=conf_liveassist_outro_carts.value(code,-1);
+
+  if(ret<0) {
+    ret=rivendellLiveassistFriendlyOutroCart();
+  }
+  return ret;
+}
+
+
 QString Config::dump() const
 {
   QString ret="";
@@ -179,6 +207,7 @@ QString Config::dump() const
   ret+="\n";
   ret+="[Paths]\n";
   ret+="EasDataDirectory="+pathsEasDataDirectory()+"\n";
+  ret+="EasBackupDirectory="+pathsEasBackupDirectory()+"\n";
   ret+="EasMessageExtension="+pathsEasMessageExtension()+"\n";
   ret+="RlmReceivePort="+QString().sprintf("%u",pathsRlmReceivePort())+"\n";
   ret+="\n";
@@ -221,6 +250,7 @@ bool Config::load()
 
   conf_paths_eas_data_directory=
     p->stringValue("Paths","EasDataDirectory","/var/eas");
+  conf_paths_eas_backup_directory=p->stringValue("Paths","EasBackupDirectory");
   conf_paths_eas_message_extension=
     p->stringValue("Paths","EasMessageExtension","txt");
   conf_paths_eas_message_extension_filter.clear();
@@ -291,6 +321,11 @@ bool Config::load()
   for(int i=0;i<eas_codes.size();i++) {
     conf_intro_carts[eas_codes[i]]=p->intValue("IntroCarts",eas_codes[i],-1);
     conf_outro_carts[eas_codes[i]]=p->intValue("OutroCarts",eas_codes[i],-1);
+
+    conf_liveassist_intro_carts[eas_codes[i]]=
+      p->intValue("LiveassistIntroCarts",eas_codes[i],-1);
+    conf_liveassist_outro_carts[eas_codes[i]]=
+      p->intValue("LiveassistOutroCarts",eas_codes[i],-1);
   }
 
   delete p;
@@ -313,10 +348,13 @@ void Config::clear()
   conf_rivendell_normalization_level=0;
   conf_rivendell_autotrim_level=0;
   conf_paths_eas_data_directory="";
+  conf_paths_eas_backup_directory="";
   conf_paths_eas_message_extension="";
   conf_paths_rlm_receive_port=0;
   conf_intro_carts.clear();
   conf_outro_carts.clear();
+  conf_liveassist_intro_carts.clear();
+  conf_liveassist_outro_carts.clear();
 }
 
 
@@ -327,10 +365,8 @@ unsigned Config::importCart(const QString &title,const QString &filename,
   unsigned numrecs=0;
   int ret=0;
   QString pathname=filename;
-  int normalization_level=0;
   if(pathname.left(1)!="/") {
     pathname=conf_paths_eas_data_directory+"/"+filename;
-    normalization_level=conf_rivendell_normalization_level;
   }
 
   if(RD_ImportCart(&carts,
@@ -341,7 +377,7 @@ unsigned Config::importCart(const QString &title,const QString &filename,
 		   0,                                   // Cart Number
 		   0,                                   // Cut Number
 		   1,                                   // Channels
-		   normalization_level,
+		   conf_rivendell_normalization_level,
 		   conf_rivendell_autotrim_level,
 		   0,                                   // Don't Use Metadata
 		   1,                                   // Create new cart/cut
